@@ -159,7 +159,7 @@ instance CallocPtr MemVTable where
     boxedPtrCalloc = callocBytes 48
 
 
--- | Construct a `MemVTable` struct initialized to zero.
+-- | Construct a t'MemVTable' struct initialized to zero.
 newZeroMemVTable :: MonadIO m => m MemVTable
 newZeroMemVTable = liftIO $ boxedPtrCalloc >>= wrapPtr MemVTable
 
@@ -223,7 +223,7 @@ instance AttrInfo MemVTableMallocFieldInfo where
         GLib.Callbacks.mk_MemVTableMallocFieldCallback (GLib.Callbacks.wrap_MemVTableMallocFieldCallback Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.MemVTable.malloc"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-MemVTable.html#g:attr:malloc"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-MemVTable.html#g:attr:malloc"
         })
 
 memVTable_malloc :: AttrLabelProxy "malloc"
@@ -285,7 +285,7 @@ instance AttrInfo MemVTableReallocFieldInfo where
         GLib.Callbacks.mk_MemVTableReallocFieldCallback (GLib.Callbacks.wrap_MemVTableReallocFieldCallback Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.MemVTable.realloc"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-MemVTable.html#g:attr:realloc"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-MemVTable.html#g:attr:realloc"
         })
 
 memVTable_realloc :: AttrLabelProxy "realloc"
@@ -300,7 +300,7 @@ memVTable_realloc = AttrLabelProxy
 -- @
 -- 'Data.GI.Base.Attributes.get' memVTable #free
 -- @
-getMemVTableFree :: MonadIO m => MemVTable -> m (Maybe GLib.Callbacks.MemVTableFreeFieldCallback_WithClosures)
+getMemVTableFree :: MonadIO m => MemVTable -> m (Maybe GLib.Callbacks.MemVTableFreeFieldCallback)
 getMemVTableFree s = liftIO $ withManagedPtr s $ \ptr -> do
     val <- peek (ptr `plusPtr` 16) :: IO (FunPtr GLib.Callbacks.C_MemVTableFreeFieldCallback)
     result <- SP.convertFunPtrIfNonNull val $ \val' -> do
@@ -334,9 +334,9 @@ instance AttrInfo MemVTableFreeFieldInfo where
     type AttrBaseTypeConstraint MemVTableFreeFieldInfo = (~) MemVTable
     type AttrAllowedOps MemVTableFreeFieldInfo = '[ 'AttrSet, 'AttrGet, 'AttrClear]
     type AttrSetTypeConstraint MemVTableFreeFieldInfo = (~) (FunPtr GLib.Callbacks.C_MemVTableFreeFieldCallback)
-    type AttrTransferTypeConstraint MemVTableFreeFieldInfo = (~)GLib.Callbacks.MemVTableFreeFieldCallback_WithClosures
+    type AttrTransferTypeConstraint MemVTableFreeFieldInfo = (~)GLib.Callbacks.MemVTableFreeFieldCallback
     type AttrTransferType MemVTableFreeFieldInfo = (FunPtr GLib.Callbacks.C_MemVTableFreeFieldCallback)
-    type AttrGetType MemVTableFreeFieldInfo = Maybe GLib.Callbacks.MemVTableFreeFieldCallback_WithClosures
+    type AttrGetType MemVTableFreeFieldInfo = Maybe GLib.Callbacks.MemVTableFreeFieldCallback
     type AttrLabel MemVTableFreeFieldInfo = "free"
     type AttrOrigin MemVTableFreeFieldInfo = MemVTable
     attrGet = getMemVTableFree
@@ -347,7 +347,7 @@ instance AttrInfo MemVTableFreeFieldInfo where
         GLib.Callbacks.mk_MemVTableFreeFieldCallback (GLib.Callbacks.wrap_MemVTableFreeFieldCallback Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.MemVTable.free"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-MemVTable.html#g:attr:free"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-MemVTable.html#g:attr:free"
         })
 
 memVTable_free :: AttrLabelProxy "free"
@@ -409,7 +409,7 @@ instance AttrInfo MemVTableCallocFieldInfo where
         GLib.Callbacks.mk_MemVTableCallocFieldCallback (GLib.Callbacks.wrap_MemVTableCallocFieldCallback Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.MemVTable.calloc"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-MemVTable.html#g:attr:calloc"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-MemVTable.html#g:attr:calloc"
         })
 
 memVTable_calloc :: AttrLabelProxy "calloc"
@@ -471,7 +471,7 @@ instance AttrInfo MemVTableTryMallocFieldInfo where
         GLib.Callbacks.mk_MemVTableTryMallocFieldCallback (GLib.Callbacks.wrap_MemVTableTryMallocFieldCallback Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.MemVTable.tryMalloc"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-MemVTable.html#g:attr:tryMalloc"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-MemVTable.html#g:attr:tryMalloc"
         })
 
 memVTable_tryMalloc :: AttrLabelProxy "tryMalloc"
@@ -533,7 +533,7 @@ instance AttrInfo MemVTableTryReallocFieldInfo where
         GLib.Callbacks.mk_MemVTableTryReallocFieldCallback (GLib.Callbacks.wrap_MemVTableTryReallocFieldCallback Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.MemVTable.tryRealloc"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-MemVTable.html#g:attr:tryRealloc"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-MemVTable.html#g:attr:tryRealloc"
         })
 
 memVTable_tryRealloc :: AttrLabelProxy "tryRealloc"
